<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://xfinitysoft.com
 * @since      1.0.0
 *
 * @package    catalog_mode_woocommerce
 * @subpackage catalog_mode_woocommerce/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    catalog_mode_woocommerce
 * @subpackage catalog_mode_woocommerce/includes
 * @author     Xfinitysoft <support@xfinitysoft.com>
 */
class catalog_mode_woocommerce {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      catalog_mode_woocommerce_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $catalog_mode_woocommerce    The string used to uniquely identify this plugin.
	 */
	protected $catalog_mode_woocommerce;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'catalog_mode_woocommerce_VERSION' ) ) {
			$this->version = catalog_mode_woocommerce_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->catalog_mode_woocommerce = 'catalog-mode-woocommerce';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - catalog_mode_woocommerce_Loader. Orchestrates the hooks of the plugin.
	 * - catalog_mode_woocommerce_i18n. Defines internationalization functionality.
	 * - catalog_mode_woocommerce_Admin. Defines all hooks for the admin area.
	 * - catalog_mode_woocommerce_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-catalog-mode-woocommerce-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-catalog-mode-woocommerce-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		if( ! class_exists( 'WP_List_Table' ) ) {
            require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
        }
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-catalog-mode-woocommerce-exclusion-list.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-catalog-mode-woocommerce-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-catalog-mode-woocommerce-public.php';
		



		$this->loader = new catalog_mode_woocommerce_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the catalog_mode_woocommerce_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new catalog_mode_woocommerce_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new catalog_mode_woocommerce_Admin( $this->get_catalog_mode_woocommerce(), $this->get_version() );
		$this->loader->add_action( 'init', $plugin_admin, 'xscmw_create_post_type' );
		$this->loader->add_action( 'init' ,$plugin_admin, 'xscmw_register_settings');
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action( 'admin_menu',$plugin_admin,'xscmw_add_menu');
		$this->loader->add_action( 'wp_ajax_xscmw_add_new_exclusion',$plugin_admin,'xscmw_add_new_exclusion');
		$this->loader->add_action( 'load-edit.php',$plugin_admin,'xscmw_admin_button_edit' );
		$this->loader->add_action( 'load-post-new.php',$plugin_admin,'xscmw_admin_button_edit');
		$this->loader->add_action( 'load-post.php',$plugin_admin,'xscmw_admin_button_edit');
		$this->loader->add_action( 'add_meta_boxes',$plugin_admin,'xscmw_add_meta_boxes',10,2);
		$this->loader->add_action( 'save_post' ,$plugin_admin, 'xscmw_save_label_post', 10,3);


	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new catalog_mode_woocommerce_Public( $this->get_catalog_mode_woocommerce(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		$this->loader->add_action( 'wp_loaded', $plugin_public, 'xscmw_custom_buttons' );
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_catalog_mode_woocommerce() {
		return $this->catalog_mode_woocommerce;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    catalog_mode_woocommerce_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
