<?php
/**
 * Core functions
 * @version 1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Get plugin data
 *
 * @return array
 */
function cwsa_get_plugin_data() {
	return CWSA()->plugin_data();
}

/**
 * Get plugin version
 *
 * @return string
 */
function cwsa_get_plugin_version() {
	return CWSA()->plugin_version();
}

function cwsa_locate_admin_template($slug) {
	$located = cwsa_locate_template('admin/' . $slug);

	if ( ! is_readable( $located ) ) {
		return '';
	}

	return $located;
}

/**
 * Get Admin templates
 *
 * @param $slug
 * @param array $args
 *
 */
function cwsa_get_admin_template( $slug, $args = array()) {
	$located = cwsa_locate_admin_template($slug);
	if ( $args && is_array( $args ) ) {
		extract( $args );
	}
	if ($located !== '') {
		include $located;
	}
}

/**
 * Get template path
 *
 * @param $template_name
 * @param string $template_path
 * @param string $default_path
 *
 * @return mixed|string|void
 */
function cwsa_get_template_path($template_name, $template_path = '', $default_path = '') {
	$path = cwsa_locate_template( $template_name, $template_path, $default_path );
	if ( !is_readable( $path ) ) {
		if (defined(WP_DEBUG) && WP_DEBUG) {
			_doing_it_wrong( __FUNCTION__, sprintf( __( '%s does not exist.', 'directory-plus' ), '<code>' . $path . '</code>' ), '2.1' );
		}
		return '';
	}

	return $path;
}

/**
 * Include file template
 *
 * @param $template_name
 * @param array $args
 * @param string $template_path
 * @param string $default_path
 */
function cwsa_get_template( $template_name, $args = array(), $template_path = '', $default_path = '' ) {
	if ( ! empty( $args ) && is_array( $args ) ) {
		extract( $args );
	}

	$located = cwsa_get_template_path($template_name, $template_path, $default_path);

	if ($located !== '') {
		$located = apply_filters( 'cwsa_get_template', $located, $template_name, $args, $template_path, $default_path );

		do_action( 'cwsa_before_template_part', $template_name, $template_path, $located, $args );

		include( $located );

		do_action( 'cwsa_after_template_part', $template_name, $template_path, $located, $args );
	}
}

/**
 * Locate a template and return the path for inclusion.
 *
 * This is the load order:
 *
 *        yourtheme        /    $template_path    /    $template_name
 *        yourtheme        /    $template_name
 *        $default_path    /    $template_name
 *
 * @access public
 *
 * @param string $template_name
 * @param string $template_path (default: '')
 * @param string $default_path (default: '')
 *
 * @return string
 */
function cwsa_locate_template( $template_name, $template_path = '', $default_path = '' ) {
	if ( ! $template_path ) {
		$template_path = CWSA()->template_path();
	}

	if ( ! $default_path ) {
		$default_path = CWSA()->plugin_dir() . 'templates/';
	}
	// Look within passed path within the theme - this is priority.
	$template = locate_template(
		array(
			trailingslashit( $template_path ) . $template_name,
		)
	);

	// Get default template/
	if ( ! $template || CWSA_TEMPLATE_DEBUG_MODE ) {
		$template = $default_path . $template_name;
	}

	// Return what we found.
	return apply_filters( 'cwsa_locate_template', $template, $template_name, $template_path );
}

/**
 * Get template part (for templates like the listing-loop).
 *
 * CWSA_TEMPLATE_DEBUG_MODE will prevent overrides in themes from taking priority.
 *
 * @access public
 * @param mixed $slug
 * @param string $name (default: '')
 */
function cwsa_get_template_part( $slug, $name = '' ) {
	$template = '';

	// Look in yourtheme/slug-name.php and yourtheme/directory-plus/slug-name.php
	if ( $name && ! CWSA_TEMPLATE_DEBUG_MODE ) {
		$template = locate_template( array( "{$slug}-{$name}.php", CWSA()->template_path() . "{$slug}-{$name}.php" ) );
	}

	// Get default slug-name.php
	if ( ! $template && $name && file_exists( CWSA()->plugin_dir() . "templates/{$slug}-{$name}.php" ) ) {
		$template = CWSA()->plugin_dir() . "templates/{$slug}-{$name}.php";
	}

	// If template file doesn't exist, look in yourtheme/slug.php and yourtheme/directory-plus/slug.php
	if ( ! $template && ! CWSA_TEMPLATE_DEBUG_MODE ) {
		$template = locate_template( array( "{$slug}.php", CWSA()->template_path() . "{$slug}.php" ) );
	}

	// Allow 3rd party plugins to filter template file from their plugin.
	$template = apply_filters( 'cwsa_get_template_part', $template, $slug, $name );

	if ( $template ) {
		load_template( $template, false );
	}
}

/**
 * Get assets handle
 *
 * @param string $handle
 *
 * @return string
 */
function cwsa_get_assets_handle($handle = '') {
	return CWSA()->get_assets_handler() . $handle;
}

/**
 * Get plugin assets url
 *
 * @param $file
 * @return string
 * @version  1.0
 */
function cwsa_get_asset_url($file) {
	if (!file_exists(CWSA()->plugin_dir($file)) || (defined('SCRIPT_DEBUG') && SCRIPT_DEBUG)) {
		$normal_file = preg_replace('/(.*)(\.min)((\.css)|(\.js))$/', '$1$3', $file);;
		if ($normal_file != $file) {
			if (file_exists(CWSA()->plugin_dir($normal_file))) {
				return CWSA()->plugin_url($normal_file);
			}
		}
	}
	return CWSA()->plugin_url($file);
}

/**
 * Get plugin file
 *
 * @param string $file
 *
 * @return string
 */
function cwsa_get_plugin_dir($file = '') {
	return CWSA()->plugin_dir($file);
}

/**
 * Get site name
 *
 * @return string
 */
function cwsa_get_site_name() {
	if ( is_multisite() ) {
		return get_network()->site_name;
	}

	/*
	 * The blogname option is escaped with esc_html on the way into the database
	 * in sanitize_option we want to reverse this for the plain text arena of emails.
	 */
	return wp_specialchars_decode( get_option( 'blogname' ), ENT_QUOTES );
}

function cwsa_get_current_url() {
	return set_url_scheme( 'http://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'] );
}

function cwsa_is_active_theme( $theme ) {
    return is_array( $theme ) ? in_array( get_template(), $theme, true ) : get_template() === $theme;
}

function cwsa_get_current_time() {
	return current_time( 'mysql', true );
}

function cwsa_get_all_roles() {
	global $wp_roles;
	if ( ! isset( $wp_roles ) ) {
		$wp_roles = new WP_Roles();
	}
	return $wp_roles->get_names();
}

function cwsa_get_all_pages() {
	$_pages = get_pages();
	$_results = array(
		'' => esc_html__('--[Select page to create sandbox]--','cwsa')
	);
	foreach ( $_pages as $p ) {
		$_results[$p->ID] = $p->post_title;
	}
	return $_results;
}

function cwsa_delete_files($target) {
	if (!file_exists($target)) {
		return;
	}
	if(is_dir($target)){
		$files = glob( $target . '/{,.}*', GLOB_BRACE ); //GLOB_MARK adds a slash to directories returned

		foreach( $files as $file_name ){
			if (("{$target}/." === $file_name) || ("{$target}/.." === $file_name)) {
				continue;
			}
			cwsa_delete_files( $file_name );
		}
		rmdir( $target );
	} elseif(is_file($target)) {
		unlink( $target );
	}
}

function cwsa_get_upload_dir($blog_id) {
	switch_to_blog( $blog_id );
	$_upload_dir = wp_upload_dir();
	restore_current_blog();

	return untrailingslashit($_upload_dir['basedir']);
}

function cwsa_session_start() {
	if (function_exists('session_status')) {
		if (session_status() == PHP_SESSION_NONE) {
			session_start();
		}
	}
	else {
		if(session_id() == '') {
			session_start();
		}
	}
}

function cwsa_get_request_sandbox_page_url() {
	switch_to_blog(1);
	if (CWSA()->options()->get_request_sandbox_page() === '') {
		$url = home_url('/');
	}
	else {
		$url = get_permalink(CWSA()->options()->get_request_sandbox_page());
	}
	restore_current_blog();
	return $url;
}

function cwsa_email_notification_list() {
	return apply_filters('cwsa_email_notification_list', array(
		'create-sandbox-notify-admin' => array(
			'name' => esc_html_x('Notify Administrator at site creation', 'email-notification-list','cwsa'),
			'recipient' => 'admin',
		),
		'create-sandbox-request' => array(
			'name' => esc_html_x('Create Sandbox Request', 'email-notification-list','cwsa'),
			'recipient' => 'user',
			'desc' => esc_html__('Turn on this email if you want to verify the sandbox creation!','desc')
		),
	));
}
function cwsa_get_site_status($site) {
	if (($site->created_date === null) && ($site->close_date === null)) {
		return array(
			'status' => 'pending',
			'text' => esc_html__('Pending','cwsa')
		);
	}
	if (($site->created_date === null) && ($site->close_date !== null)) {
		return array(
			'status' => 'cancelled',
			'text' => esc_html__('Cancelled','cwsa')
		);
	}
	if (($site->created_date !== null) && ($site->close_date === null)) {
		return array(
			'status' => 'running',
			'text' => esc_html__('Running','cwsa')
		);
	}
	return array(
		'status' => 'closed',
		'text' => esc_html__('Closed','cwsa')
	);
}